==> newlife-components-1.4.20.tgz: package/src/lib/http/axios/handler.js <==
import UtilLoading from "../../../utils/js/UtilLoading";
import UtilMessage from "../../../utils/js/UtilMessage";
import UtilNotEmpty from "../../../utils/js/UtilNotEmpty";
import UtilEmpty from "../../../utils/js/UtilEmpty";
import NfStore from "../../vuex/index";
import {OAUTH2_TOKEN} from "../../../utils/const/NfConst"
import RefreshToken from "./RefreshToken";

let rt = new RefreshToken();

/**
 * 拦截请求
 * @param config
 * @returns {*}
 */
function handlerRequest(config) {
  //若参数为空，设置传空对象
  if (UtilEmpty.obj(config.data)) {
    config.data = {};
  }
  //如果正在进行刷新token,返回一个resolve的Promise
  let {url} = config;
  if (rt.refreshTokenFlag && url.indexOf(OAUTH2_TOKEN.url.refresh_token) === -1) {
    rt.createCacheRequest(config);
    return Promise.resolve();
  }
  //统一携带token
  let token = NfStore.instance.getters.loginToken;
  if (UtilNotEmpty.obj(token) && UtilNotEmpty.string(token['access_token'])) {
    config.headers.Authorization = "Bearer " + token['access_token'];
  }
  //遮罩加载
  UtilLoading.showLoading();
  return config;
}

/**
 * 请求失败未发出去，返回
 * @param error
 * @returns {*}
 */
function handlerRequestErrors(error) {
  UtilLoading.hideLoading();
  return error;
}

/**
 * 响应成功
 * @param response
 */
function handlerResponse(response) {
  UtilLoading.hideLoading();
  //下载流响应直接放行
  const headers = response.headers;
  if (headers['content-type'] === "application/octet-stream") {
    return response;
  }
  //json数据响应处理
  const {status, code, message, vdata} = response.data;
  if (status) {
    if (status === '666') {
      //返回数据进入业务
      return vdata;
    } else if (status === '555') {
      //业务异常
      if (code) {
        if (code === OAUTH2_TOKEN.code.access_token_exp_code) {
          rt.refreshTokenAndSendRequests(response.config);
        } else if (code === OAUTH2_TOKEN.code.refresh_token_exp_code) {
          //refresh_token过期，跳转至登录重新登录
          UtilMessage.error(message ? message : "长时间未操作，请重新登录");
          setTimeout(rt.returnLoginPage, 1000);
        } else {
          //其他业务异常提示
          UtilMessage.error(message ? message : "出错了，请刷新后重试");
        }
      }
    } else if (status === '444') {
      //系统代码Bug错误
      UtilMessage.error(message ? message : "系统故障，请联系管理员");
    } else {
      UtilMessage.error("status错误！");
    }
  }
  return Promise.reject(response.data);
}

/**
 * 响应失败
 * @param errors
 * @returns {Promise|Promise}
 */
function handlerResponseErrors(errors) {
  UtilLoading.hideLoading();
  let errorMessage = {message: "服务器响应失败"};
  if (errors.response) {
    switch (errors.response.status) {
      case 400:
        errorMessage.message = '请求错误';
        break;
      case 401:
        errorMessage.message = '未授权，请登录';
        break;
      case 403:
        errorMessage.message = '拒绝访问';
        break;
      case 404:
        errorMessage.message = '请求资源不存在';
        break;
      case 408:
        errorMessage.message = '请求超时';
        break;
      case 500:
        errorMessage.message = '服务器内部错误';
        break;
      case 501:
        errorMessage.message = '服务未实现';
        break;
      case 502:
        errorMessage.message = '网关错误';
        break;
      case 503:
        errorMessage.message = '服务不可用';
        break;
      case 504:
        errorMessage.message = '网关超时';
        break;
      case 505:
        errorMessage.message = 'HTTP版本不受支持';
        break;
      default:
        errorMessage.message = '请求错误,请联系管理员';
    }
  } else {
    //网络不通处理
    errorMessage = {message: "断网了，请检查您的网络"};
  }
  UtilMessage.error(errorMessage.message);
  return Promise.reject(errorMessage);
}

export default {
  handlerRequest,
  handlerRequestErrors,
  handlerResponse,
  handlerResponseErrors
}

==> newlife-components-1.5.15.tgz: package/src/lib/http/axios/handler.js <==
import UtilLoading from "../../../utils/js/UtilLoading";
import UtilMessage from "../../../utils/js/UtilMessage";
import UtilNotEmpty from "../../../utils/js/UtilNotEmpty";
import UtilEmpty from "../../../utils/js/UtilEmpty";
import NfStore from "../../vuex/index";
import {CLIENT_INIT} from "../../../utils/const/NfConst"
import RefreshToken from "./RefreshToken";

let rt = new RefreshToken();

/**
 * 拦截请求
 * @param config
 * @returns {*}
 */
function handlerRequest(config) {
  //若参数为空，设置传空对象
  if (UtilEmpty.obj(config.data)) {
    config.data = {};
  }
  //如果正在进行刷新token,返回一个resolve的Promise
  let {url} = config;
  if (rt.refreshTokenFlag && url.indexOf(CLIENT_INIT.base_url.refresh_token) === -1) {
    rt.createCacheRequest(config);
    return Promise.resolve();
  }
  //统一携带token
  let token = NfStore.instance.getters.loginToken;
  if (UtilNotEmpty.obj(token) && UtilNotEmpty.string(token['access_token'])) {
    config.headers.Authorization = "Bearer " + token['access_token'];
  }
  //遮罩加载
  UtilLoading.showLoading();
  return config;
}

/**
 * 请求失败未发出去，返回
 * @param error
 * @returns {*}
 */
function handlerRequestErrors(error) {
  UtilLoading.hideLoading();
  return error;
}

/**
 * 响应成功
 * @param response
 */
function handlerResponse(response) {
  UtilLoading.hideLoading();
  //下载流响应直接放行
  const headers = response.headers;
  const contentType = headers['content-type'];
  if (UtilNotEmpty.string(contentType) && contentType.indexOf("application/octet-stream") !== -1) {
    return response;
  }
  //json数据响应处理
  const {status, code, message, vdata} = response.data;
  if (status) {
    if (status === '666') {
      //返回数据进入业务
      return vdata;
    } else if (status === '555') {
      //业务异常
      if (code) {
        if (code === CLIENT_INIT.status.access_token_exp_code) {
          rt.refreshTokenAndSendRequests(response.config);
        } else if (code === CLIENT_INIT.status.refresh_token_exp_code) {
          //refresh_token过期，跳转至登录重新登录
          UtilMessage.error(message ? message : "长时间未操作，请重新登录");
          setTimeout(rt.returnLoginPage, 600);
        } else {
          //其他业务异常提示
          UtilMessage.error(message ? message : "出错了，请刷新后重试");
        }
      }
    } else if (status === '444') {
      //系统代码Bug错误
      UtilMessage.error(message ? message : "系统故障，请联系管理员");
    } else {
      UtilMessage.error("status错误！");
    }
  }
  return Promise.reject(response.data);
}

/**
 * 响应失败
 * @param errors
 * @returns {Promise|Promise}
 */
function handlerResponseErrors(errors) {
  UtilLoading.hideLoading();
  let errorMessage = {message: "服务器响应失败"};
  if (errors.response) {
    switch (errors.response.status) {
      case 400:
        errorMessage.message = '请求错误';
        break;
      case 401:
        errorMessage.message = '未授权，请登录';
        break;
      case 403:
        errorMessage.message = '拒绝访问';
        break;
      case 404:
        errorMessage.message = '请求资源不存在';
        break;
      case 408:
        errorMessage.message = '请求超时';
        break;
      case 500:
        errorMessage.message = '服务器内部错误';
        break;
      case 501:
        errorMessage.message = '服务未实现';
        break;
      case 502:
        errorMessage.message = '网关错误';
        break;
      case 503:
        errorMessage.message = '服务不可用';
        break;
      case 504:
        errorMessage.message = '网关超时';
        break;
      case 505:
        errorMessage.message = 'HTTP版本不受支持';
        break;
      default:
        errorMessage.message = '请求错误,请联系管理员';
    }
  } else {
    //网络不通处理
    errorMessage = {message: "断网了，请检查您的网络"};
  }
  UtilMessage.error(errorMessage.message);
  return Promise.reject(errorMessage);
}

export default {
  handlerRequest,
  handlerRequestErrors,
  handlerResponse,
  handlerResponseErrors
}
